import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleComputeInstanceGroupConfig extends cdktf.TerraformMetaArguments {
    /**
    * An optional textual description of the instance group.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#description GoogleComputeInstanceGroup#description}
    */
    readonly description?: string;
    /**
    * List of instances in the group. They should be given as self_link URLs. When adding instances they must all be in the same network and zone as the instance group.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#instances GoogleComputeInstanceGroup#instances}
    */
    readonly instances?: string[];
    /**
    * The name of the instance group. Must be 1-63 characters long and comply with RFC1035. Supported characters include lowercase letters, numbers, and hyphens.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#name GoogleComputeInstanceGroup#name}
    */
    readonly name: string;
    /**
    * The URL of the network the instance group is in. If this is different from the network where the instances are in, the creation fails. Defaults to the network where the instances are in (if neither network nor instances is specified, this field will be blank).
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#network GoogleComputeInstanceGroup#network}
    */
    readonly network?: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#project GoogleComputeInstanceGroup#project}
    */
    readonly project?: string;
    /**
    * The zone that this instance group should be created in.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#zone GoogleComputeInstanceGroup#zone}
    */
    readonly zone?: string;
    /**
    * named_port block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#named_port GoogleComputeInstanceGroup#named_port}
    */
    readonly namedPort?: GoogleComputeInstanceGroupNamedPort[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#timeouts GoogleComputeInstanceGroup#timeouts}
    */
    readonly timeouts?: GoogleComputeInstanceGroupTimeouts;
}
export interface GoogleComputeInstanceGroupNamedPort {
    /**
    * The name which the port will be mapped to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#name GoogleComputeInstanceGroup#name}
    */
    readonly name: string;
    /**
    * The port number to map the name to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#port GoogleComputeInstanceGroup#port}
    */
    readonly port: number;
}
export declare function googleComputeInstanceGroupNamedPortToTerraform(struct?: GoogleComputeInstanceGroupNamedPort | cdktf.IResolvable): any;
export interface GoogleComputeInstanceGroupTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#create GoogleComputeInstanceGroup#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#delete GoogleComputeInstanceGroup#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group#update GoogleComputeInstanceGroup#update}
    */
    readonly update?: string;
}
export declare function googleComputeInstanceGroupTimeoutsToTerraform(struct?: GoogleComputeInstanceGroupTimeoutsOutputReference | GoogleComputeInstanceGroupTimeouts | cdktf.IResolvable): any;
export declare class GoogleComputeInstanceGroupTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleComputeInstanceGroupTimeouts | undefined;
    set internalValue(value: GoogleComputeInstanceGroupTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group google_compute_instance_group}
*/
export declare class GoogleComputeInstanceGroup extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_compute_instance_group";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_compute_instance_group google_compute_instance_group} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleComputeInstanceGroupConfig
    */
    constructor(scope: Construct, id: string, config: GoogleComputeInstanceGroupConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _instances?;
    get instances(): string[];
    set instances(value: string[]);
    resetInstances(): void;
    get instancesInput(): string[] | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _network?;
    get network(): string;
    set network(value: string);
    resetNetwork(): void;
    get networkInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    get selfLink(): string;
    get size(): number;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _namedPort?;
    get namedPort(): GoogleComputeInstanceGroupNamedPort[] | cdktf.IResolvable;
    set namedPort(value: GoogleComputeInstanceGroupNamedPort[] | cdktf.IResolvable);
    resetNamedPort(): void;
    get namedPortInput(): cdktf.IResolvable | GoogleComputeInstanceGroupNamedPort[] | undefined;
    private _timeouts;
    get timeouts(): GoogleComputeInstanceGroupTimeoutsOutputReference;
    putTimeouts(value: GoogleComputeInstanceGroupTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleComputeInstanceGroupTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
