import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDatastoreIndexConfig extends cdktf.TerraformMetaArguments {
    /**
    * Policy for including ancestors in the index. Default value: "NONE" Possible values: ["NONE", "ALL_ANCESTORS"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#ancestor GoogleDatastoreIndex#ancestor}
    */
    readonly ancestor?: string;
    /**
    * The entity kind which the index applies to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#kind GoogleDatastoreIndex#kind}
    */
    readonly kind: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#project GoogleDatastoreIndex#project}
    */
    readonly project?: string;
    /**
    * properties block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#properties GoogleDatastoreIndex#properties}
    */
    readonly properties?: GoogleDatastoreIndexProperties[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#timeouts GoogleDatastoreIndex#timeouts}
    */
    readonly timeouts?: GoogleDatastoreIndexTimeouts;
}
export interface GoogleDatastoreIndexProperties {
    /**
    * The direction the index should optimize for sorting. Possible values: ["ASCENDING", "DESCENDING"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#direction GoogleDatastoreIndex#direction}
    */
    readonly direction: string;
    /**
    * The property name to index.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#name GoogleDatastoreIndex#name}
    */
    readonly name: string;
}
export declare function googleDatastoreIndexPropertiesToTerraform(struct?: GoogleDatastoreIndexProperties | cdktf.IResolvable): any;
export interface GoogleDatastoreIndexTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#create GoogleDatastoreIndex#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index#delete GoogleDatastoreIndex#delete}
    */
    readonly delete?: string;
}
export declare function googleDatastoreIndexTimeoutsToTerraform(struct?: GoogleDatastoreIndexTimeoutsOutputReference | GoogleDatastoreIndexTimeouts | cdktf.IResolvable): any;
export declare class GoogleDatastoreIndexTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDatastoreIndexTimeouts | undefined;
    set internalValue(value: GoogleDatastoreIndexTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index google_datastore_index}
*/
export declare class GoogleDatastoreIndex extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_datastore_index";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_datastore_index google_datastore_index} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDatastoreIndexConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDatastoreIndexConfig);
    private _ancestor?;
    get ancestor(): string;
    set ancestor(value: string);
    resetAncestor(): void;
    get ancestorInput(): string | undefined;
    get id(): string;
    get indexId(): string;
    private _kind?;
    get kind(): string;
    set kind(value: string);
    get kindInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _properties?;
    get properties(): GoogleDatastoreIndexProperties[] | cdktf.IResolvable;
    set properties(value: GoogleDatastoreIndexProperties[] | cdktf.IResolvable);
    resetProperties(): void;
    get propertiesInput(): cdktf.IResolvable | GoogleDatastoreIndexProperties[] | undefined;
    private _timeouts;
    get timeouts(): GoogleDatastoreIndexTimeoutsOutputReference;
    putTimeouts(value: GoogleDatastoreIndexTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleDatastoreIndexTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
