import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDialogflowCxEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * The human-readable description of the environment. The maximum length is 500 characters. If exceeded, the request is rejected.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#description GoogleDialogflowCxEnvironment#description}
    */
    readonly description?: string;
    /**
    * The human-readable name of the environment (unique in an agent). Limit of 64 characters.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#display_name GoogleDialogflowCxEnvironment#display_name}
    */
    readonly displayName: string;
    /**
    * The Agent to create an Environment for.
  Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#parent GoogleDialogflowCxEnvironment#parent}
    */
    readonly parent?: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#timeouts GoogleDialogflowCxEnvironment#timeouts}
    */
    readonly timeouts?: GoogleDialogflowCxEnvironmentTimeouts;
    /**
    * version_configs block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#version_configs GoogleDialogflowCxEnvironment#version_configs}
    */
    readonly versionConfigs: GoogleDialogflowCxEnvironmentVersionConfigs[] | cdktf.IResolvable;
}
export interface GoogleDialogflowCxEnvironmentTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#create GoogleDialogflowCxEnvironment#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#delete GoogleDialogflowCxEnvironment#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#update GoogleDialogflowCxEnvironment#update}
    */
    readonly update?: string;
}
export declare function googleDialogflowCxEnvironmentTimeoutsToTerraform(struct?: GoogleDialogflowCxEnvironmentTimeoutsOutputReference | GoogleDialogflowCxEnvironmentTimeouts | cdktf.IResolvable): any;
export declare class GoogleDialogflowCxEnvironmentTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDialogflowCxEnvironmentTimeouts | undefined;
    set internalValue(value: GoogleDialogflowCxEnvironmentTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
export interface GoogleDialogflowCxEnvironmentVersionConfigs {
    /**
    * Format: projects/{{project}}/locations/{{location}}/agents/{{agent}}/flows/{{flow}}/versions/{{version}}.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment#version GoogleDialogflowCxEnvironment#version}
    */
    readonly version: string;
}
export declare function googleDialogflowCxEnvironmentVersionConfigsToTerraform(struct?: GoogleDialogflowCxEnvironmentVersionConfigs | cdktf.IResolvable): any;
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment google_dialogflow_cx_environment}
*/
export declare class GoogleDialogflowCxEnvironment extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dialogflow_cx_environment";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_dialogflow_cx_environment google_dialogflow_cx_environment} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDialogflowCxEnvironmentConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDialogflowCxEnvironmentConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _displayName?;
    get displayName(): string;
    set displayName(value: string);
    get displayNameInput(): string | undefined;
    get id(): string;
    get name(): string;
    private _parent?;
    get parent(): string;
    set parent(value: string);
    resetParent(): void;
    get parentInput(): string | undefined;
    get updateTime(): string;
    private _timeouts;
    get timeouts(): GoogleDialogflowCxEnvironmentTimeoutsOutputReference;
    putTimeouts(value: GoogleDialogflowCxEnvironmentTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleDialogflowCxEnvironmentTimeouts | undefined;
    private _versionConfigs?;
    get versionConfigs(): GoogleDialogflowCxEnvironmentVersionConfigs[] | cdktf.IResolvable;
    set versionConfigs(value: GoogleDialogflowCxEnvironmentVersionConfigs[] | cdktf.IResolvable);
    get versionConfigsInput(): cdktf.IResolvable | GoogleDialogflowCxEnvironmentVersionConfigs[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
