import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleDnsPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
    * A textual description field. Defaults to 'Managed by Terraform'.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#description GoogleDnsPolicy#description}
    */
    readonly description?: string;
    /**
    * Allows networks bound to this policy to receive DNS queries sent
  by VMs or applications over VPN connections. When enabled, a
  virtual IP address will be allocated from each of the sub-networks
  that are bound to this policy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#enable_inbound_forwarding GoogleDnsPolicy#enable_inbound_forwarding}
    */
    readonly enableInboundForwarding?: boolean | cdktf.IResolvable;
    /**
    * Controls whether logging is enabled for the networks bound to this policy.
  Defaults to no logging if not set.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#enable_logging GoogleDnsPolicy#enable_logging}
    */
    readonly enableLogging?: boolean | cdktf.IResolvable;
    /**
    * User assigned name for this policy.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#name GoogleDnsPolicy#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#project GoogleDnsPolicy#project}
    */
    readonly project?: string;
    /**
    * alternative_name_server_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#alternative_name_server_config GoogleDnsPolicy#alternative_name_server_config}
    */
    readonly alternativeNameServerConfig?: GoogleDnsPolicyAlternativeNameServerConfig;
    /**
    * networks block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#networks GoogleDnsPolicy#networks}
    */
    readonly networks?: GoogleDnsPolicyNetworks[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#timeouts GoogleDnsPolicy#timeouts}
    */
    readonly timeouts?: GoogleDnsPolicyTimeouts;
}
export interface GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers {
    /**
    * Forwarding path for this TargetNameServer. If unset or 'default' Cloud DNS will make forwarding
  decision based on address ranges, i.e. RFC1918 addresses go to the VPC, Non-RFC1918 addresses go
  to the Internet. When set to 'private', Cloud DNS will always send queries through VPC for this target Possible values: ["default", "private"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#forwarding_path GoogleDnsPolicy#forwarding_path}
    */
    readonly forwardingPath?: string;
    /**
    * IPv4 address to forward to.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#ipv4_address GoogleDnsPolicy#ipv4_address}
    */
    readonly ipv4Address: string;
}
export declare function googleDnsPolicyAlternativeNameServerConfigTargetNameServersToTerraform(struct?: GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers | cdktf.IResolvable): any;
export interface GoogleDnsPolicyAlternativeNameServerConfig {
    /**
    * target_name_servers block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#target_name_servers GoogleDnsPolicy#target_name_servers}
    */
    readonly targetNameServers: GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers[] | cdktf.IResolvable;
}
export declare function googleDnsPolicyAlternativeNameServerConfigToTerraform(struct?: GoogleDnsPolicyAlternativeNameServerConfigOutputReference | GoogleDnsPolicyAlternativeNameServerConfig): any;
export declare class GoogleDnsPolicyAlternativeNameServerConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDnsPolicyAlternativeNameServerConfig | undefined;
    set internalValue(value: GoogleDnsPolicyAlternativeNameServerConfig | undefined);
    private _targetNameServers?;
    get targetNameServers(): GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers[] | cdktf.IResolvable;
    set targetNameServers(value: GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers[] | cdktf.IResolvable);
    get targetNameServersInput(): cdktf.IResolvable | GoogleDnsPolicyAlternativeNameServerConfigTargetNameServers[] | undefined;
}
export interface GoogleDnsPolicyNetworks {
    /**
    * The id or fully qualified URL of the VPC network to forward queries to.
  This should be formatted like 'projects/{project}/global/networks/{network}' or
  'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}'
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#network_url GoogleDnsPolicy#network_url}
    */
    readonly networkUrl: string;
}
export declare function googleDnsPolicyNetworksToTerraform(struct?: GoogleDnsPolicyNetworks | cdktf.IResolvable): any;
export interface GoogleDnsPolicyTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#create GoogleDnsPolicy#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#delete GoogleDnsPolicy#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy#update GoogleDnsPolicy#update}
    */
    readonly update?: string;
}
export declare function googleDnsPolicyTimeoutsToTerraform(struct?: GoogleDnsPolicyTimeoutsOutputReference | GoogleDnsPolicyTimeouts | cdktf.IResolvable): any;
export declare class GoogleDnsPolicyTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleDnsPolicyTimeouts | undefined;
    set internalValue(value: GoogleDnsPolicyTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy google_dns_policy}
*/
export declare class GoogleDnsPolicy extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_dns_policy";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_dns_policy google_dns_policy} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleDnsPolicyConfig
    */
    constructor(scope: Construct, id: string, config: GoogleDnsPolicyConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    private _enableInboundForwarding?;
    get enableInboundForwarding(): boolean | cdktf.IResolvable;
    set enableInboundForwarding(value: boolean | cdktf.IResolvable);
    resetEnableInboundForwarding(): void;
    get enableInboundForwardingInput(): boolean | cdktf.IResolvable | undefined;
    private _enableLogging?;
    get enableLogging(): boolean | cdktf.IResolvable;
    set enableLogging(value: boolean | cdktf.IResolvable);
    resetEnableLogging(): void;
    get enableLoggingInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _alternativeNameServerConfig;
    get alternativeNameServerConfig(): GoogleDnsPolicyAlternativeNameServerConfigOutputReference;
    putAlternativeNameServerConfig(value: GoogleDnsPolicyAlternativeNameServerConfig): void;
    resetAlternativeNameServerConfig(): void;
    get alternativeNameServerConfigInput(): GoogleDnsPolicyAlternativeNameServerConfig | undefined;
    private _networks?;
    get networks(): GoogleDnsPolicyNetworks[] | cdktf.IResolvable;
    set networks(value: GoogleDnsPolicyNetworks[] | cdktf.IResolvable);
    resetNetworks(): void;
    get networksInput(): cdktf.IResolvable | GoogleDnsPolicyNetworks[] | undefined;
    private _timeouts;
    get timeouts(): GoogleDnsPolicyTimeoutsOutputReference;
    putTimeouts(value: GoogleDnsPolicyTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleDnsPolicyTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
