import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface GoogleFilestoreInstanceConfig extends cdktf.TerraformMetaArguments {
    /**
    * A description of the instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#description GoogleFilestoreInstance#description}
    */
    readonly description?: string;
    /**
    * Resource labels to represent user-provided metadata.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#labels GoogleFilestoreInstance#labels}
    */
    readonly labels?: {
        [key: string]: string;
    };
    /**
    * The name of the location of the instance. This can be a region for ENTERPRISE tier instances.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#location GoogleFilestoreInstance#location}
    */
    readonly location?: string;
    /**
    * The resource name of the instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#name GoogleFilestoreInstance#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#project GoogleFilestoreInstance#project}
    */
    readonly project?: string;
    /**
    * The service tier of the instance.
  Possible values include: STANDARD, PREMIUM, BASIC_HDD, BASIC_SSD, HIGH_SCALE_SSD and ENTERPRISE (beta only)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#tier GoogleFilestoreInstance#tier}
    */
    readonly tier: string;
    /**
    * The name of the Filestore zone of the instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#zone GoogleFilestoreInstance#zone}
    */
    readonly zone?: string;
    /**
    * file_shares block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#file_shares GoogleFilestoreInstance#file_shares}
    */
    readonly fileShares: GoogleFilestoreInstanceFileShares;
    /**
    * networks block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#networks GoogleFilestoreInstance#networks}
    */
    readonly networks: GoogleFilestoreInstanceNetworks[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#timeouts GoogleFilestoreInstance#timeouts}
    */
    readonly timeouts?: GoogleFilestoreInstanceTimeouts;
}
export interface GoogleFilestoreInstanceFileSharesNfsExportOptions {
    /**
    * Either READ_ONLY, for allowing only read requests on the exported directory,
  or READ_WRITE, for allowing both read and write requests. The default is READ_WRITE. Default value: "READ_WRITE" Possible values: ["READ_ONLY", "READ_WRITE"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#access_mode GoogleFilestoreInstance#access_mode}
    */
    readonly accessMode?: string;
    /**
    * An integer representing the anonymous group id with a default value of 65534.
  Anon_gid may only be set with squashMode of ROOT_SQUASH. An error will be returned
  if this field is specified for other squashMode settings.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#anon_gid GoogleFilestoreInstance#anon_gid}
    */
    readonly anonGid?: number;
    /**
    * An integer representing the anonymous user id with a default value of 65534.
  Anon_uid may only be set with squashMode of ROOT_SQUASH. An error will be returned
  if this field is specified for other squashMode settings.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#anon_uid GoogleFilestoreInstance#anon_uid}
    */
    readonly anonUid?: number;
    /**
    * List of either IPv4 addresses, or ranges in CIDR notation which may mount the file share.
  Overlapping IP ranges are not allowed, both within and across NfsExportOptions. An error will be returned.
  The limit is 64 IP ranges/addresses for each FileShareConfig among all NfsExportOptions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#ip_ranges GoogleFilestoreInstance#ip_ranges}
    */
    readonly ipRanges?: string[];
    /**
    * Either NO_ROOT_SQUASH, for allowing root access on the exported directory, or ROOT_SQUASH,
  for not allowing root access. The default is NO_ROOT_SQUASH. Default value: "NO_ROOT_SQUASH" Possible values: ["NO_ROOT_SQUASH", "ROOT_SQUASH"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#squash_mode GoogleFilestoreInstance#squash_mode}
    */
    readonly squashMode?: string;
}
export declare function googleFilestoreInstanceFileSharesNfsExportOptionsToTerraform(struct?: GoogleFilestoreInstanceFileSharesNfsExportOptions | cdktf.IResolvable): any;
export interface GoogleFilestoreInstanceFileShares {
    /**
    * File share capacity in GiB. This must be at least 1024 GiB
  for the standard tier, or 2560 GiB for the premium tier.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#capacity_gb GoogleFilestoreInstance#capacity_gb}
    */
    readonly capacityGb: number;
    /**
    * The name of the fileshare (16 characters or less)
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#name GoogleFilestoreInstance#name}
    */
    readonly name: string;
    /**
    * nfs_export_options block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#nfs_export_options GoogleFilestoreInstance#nfs_export_options}
    */
    readonly nfsExportOptions?: GoogleFilestoreInstanceFileSharesNfsExportOptions[] | cdktf.IResolvable;
}
export declare function googleFilestoreInstanceFileSharesToTerraform(struct?: GoogleFilestoreInstanceFileSharesOutputReference | GoogleFilestoreInstanceFileShares): any;
export declare class GoogleFilestoreInstanceFileSharesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFilestoreInstanceFileShares | undefined;
    set internalValue(value: GoogleFilestoreInstanceFileShares | undefined);
    private _capacityGb?;
    get capacityGb(): number;
    set capacityGb(value: number);
    get capacityGbInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _nfsExportOptions?;
    get nfsExportOptions(): GoogleFilestoreInstanceFileSharesNfsExportOptions[] | cdktf.IResolvable;
    set nfsExportOptions(value: GoogleFilestoreInstanceFileSharesNfsExportOptions[] | cdktf.IResolvable);
    resetNfsExportOptions(): void;
    get nfsExportOptionsInput(): cdktf.IResolvable | GoogleFilestoreInstanceFileSharesNfsExportOptions[] | undefined;
}
export interface GoogleFilestoreInstanceNetworks {
    /**
    * The network connect mode of the Filestore instance.
  If not provided, the connect mode defaults to
  DIRECT_PEERING. Default value: "DIRECT_PEERING" Possible values: ["DIRECT_PEERING", "PRIVATE_SERVICE_ACCESS"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#connect_mode GoogleFilestoreInstance#connect_mode}
    */
    readonly connectMode?: string;
    /**
    * IP versions for which the instance has
  IP addresses assigned. Possible values: ["ADDRESS_MODE_UNSPECIFIED", "MODE_IPV4", "MODE_IPV6"]
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#modes GoogleFilestoreInstance#modes}
    */
    readonly modes: string[];
    /**
    * The name of the GCE VPC network to which the
  instance is connected.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#network GoogleFilestoreInstance#network}
    */
    readonly network: string;
    /**
    * A /29 CIDR block that identifies the range of IP
  addresses reserved for this instance.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#reserved_ip_range GoogleFilestoreInstance#reserved_ip_range}
    */
    readonly reservedIpRange?: string;
}
export declare function googleFilestoreInstanceNetworksToTerraform(struct?: GoogleFilestoreInstanceNetworks | cdktf.IResolvable): any;
export interface GoogleFilestoreInstanceTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#create GoogleFilestoreInstance#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#delete GoogleFilestoreInstance#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance#update GoogleFilestoreInstance#update}
    */
    readonly update?: string;
}
export declare function googleFilestoreInstanceTimeoutsToTerraform(struct?: GoogleFilestoreInstanceTimeoutsOutputReference | GoogleFilestoreInstanceTimeouts | cdktf.IResolvable): any;
export declare class GoogleFilestoreInstanceTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): GoogleFilestoreInstanceTimeouts | undefined;
    set internalValue(value: GoogleFilestoreInstanceTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance google_filestore_instance}
*/
export declare class GoogleFilestoreInstance extends cdktf.TerraformResource {
    static readonly tfResourceType = "google_filestore_instance";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google-beta/r/google_filestore_instance google_filestore_instance} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options GoogleFilestoreInstanceConfig
    */
    constructor(scope: Construct, id: string, config: GoogleFilestoreInstanceConfig);
    get createTime(): string;
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get etag(): string;
    get id(): string;
    private _labels?;
    get labels(): {
        [key: string]: string;
    };
    set labels(value: {
        [key: string]: string;
    });
    resetLabels(): void;
    get labelsInput(): {
        [key: string]: string;
    } | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    resetLocation(): void;
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _tier?;
    get tier(): string;
    set tier(value: string);
    get tierInput(): string | undefined;
    private _zone?;
    get zone(): string;
    set zone(value: string);
    resetZone(): void;
    get zoneInput(): string | undefined;
    private _fileShares;
    get fileShares(): GoogleFilestoreInstanceFileSharesOutputReference;
    putFileShares(value: GoogleFilestoreInstanceFileShares): void;
    get fileSharesInput(): GoogleFilestoreInstanceFileShares | undefined;
    private _networks?;
    get networks(): GoogleFilestoreInstanceNetworks[] | cdktf.IResolvable;
    set networks(value: GoogleFilestoreInstanceNetworks[] | cdktf.IResolvable);
    get networksInput(): cdktf.IResolvable | GoogleFilestoreInstanceNetworks[] | undefined;
    private _timeouts;
    get timeouts(): GoogleFilestoreInstanceTimeoutsOutputReference;
    putTimeouts(value: GoogleFilestoreInstanceTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): GoogleFilestoreInstanceTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
